@@ -1,7 +1,7 @@
 package Data::Dmp;
 
 our $DATE = '2016-04-30'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $VERSION = '0.19'; # VERSION
 
 use 5.010001;
 use strict;
@@ -92,7 +92,11 @@ sub _dump {
                      # perl does several normalizations to number literal, e.g.
                      # "+1" becomes 1, 0123 is octal literal, etc. make sure we
                      # only leave out quote when the number is not normalized
-                     $val eq $val+0
+                     $val eq $val+0 &&
+                     # perl also doesn't recognize Inf and NaN as numeric
+                     # literals (ref: perldata) so these unquoted literals will
+                     # choke under 'use strict "subs"
+                     $val !~ /\A-?(?:inf(?:inity)?|nan)\z/i
                  ) {
             return $val;
         } else {
@@ -198,7 +202,7 @@ Data::Dmp - Dump Perl data structures as Perl code
 
 =head1 VERSION
 
-This document describes version 0.18 of Data::Dmp (from Perl distribution Data-Dmp), released on 2016-04-30.
+This document describes version 0.19 of Data::Dmp (from Perl distribution Data-Dmp), released on 2016-04-30.
 
 =head1 SYNOPSIS
 
@@ -260,21 +264,21 @@ Note that without the pragmas, the dump might be incorrect.
 
  [1..10]:
                       Rate    Data::Dump Data::Dumper Data::Dmp
- Data::Dump    28085+-32/s            --       -68.2%    -76.6%
- Data::Dumper 88260+-100/s 214.26+-0.51%           --    -26.3%
- Data::Dmp    119782+-41/s   326.5+-0.5% 35.72+-0.17%        --
+ Data::Dump    28111+-32/s            --       -67.7%    -74.9%
+ Data::Dumper 86920+-100/s  209.19+-0.5%           --    -22.4%
+ Data::Dmp     112028+-0/s 298.53+-0.45% 28.89+-0.15%        --
  
  [1..100]:
-                        Rate   Data::Dump   Data::Dmp Data::Dumper
- Data::Dump    3390.4+-5.3/s           --      -77.0%       -77.5%
- Data::Dmp    14734.4+-5.2/s 334.6+-0.69%          --        -2.1%
- Data::Dumper    15047+-71/s  343.8+-2.2% 2.12+-0.48%           --
+                       Rate  Data::Dump   Data::Dmp Data::Dumper
+ Data::Dump   3353.9+-6.9/s          --      -76.2%       -77.5%
+ Data::Dmp      14119+-21/s   321+-1.1%          --        -5.2%
+ Data::Dumper   14897+-71/s 344.2+-2.3% 5.51+-0.53%           --
  
  Some mixed structure:
-                     Rate    Data::Dump    Data::Dmp Data::Dumper
- Data::Dump    8147+-14/s            --       -70.5%       -80.9%
- Data::Dmp    27626+-39/s 239.09+-0.76%           --       -35.2%
- Data::Dumper 42609+-45/s     423+-1.1% 54.23+-0.27%           --
+                     Rate   Data::Dump    Data::Dmp Data::Dumper
+ Data::Dump    8200+-17/s           --       -69.6%       -80.9%
+ Data::Dmp    26968+-47/s 228.9+-0.91%           --       -37.2%
+ Data::Dumper 42964+-47/s    424+-1.3% 59.32+-0.33%           --
 
 =head1 FUNCTIONS
 
